@@ -4,6 +4,7 @@ mod attachment;
 mod base64_payload;
 mod binary;
 mod event_stream;
+mod form;
 mod html;
 mod json;
 mod plain_text;
@@ -13,7 +14,7 @@ use poem::{Request, RequestBody, Result};
 
 pub use self::{
     attachment::Attachment, base64_payload::Base64, binary::Binary, event_stream::EventStream,
-    html::Html, json::Json, plain_text::PlainText, response::Response,
+    form::Form, html::Html, json::Json, plain_text::PlainText, response::Response,
 };
 use crate::registry::{MetaSchemaRef, Registry};
 
